import { TempstreamJSX, Templatable } from "tempstream";
import { BaseContext } from "koa";
import { StatefulPage } from "@sealcode/sealgen";
import html from "../html.js";
import { get_state, HA_RESPONSE } from "../ha_api.js";
import { sleep } from "../util.js";

export const actionName = "Dashboard";

const actions = {
	add: (state: State, inputs: Record<string, string>) => {
		console.log({ inputs });
		return {
			...state,
			elements: [...state.elements, inputs.element_to_add || "new element"],
		};
	},
	remove: (state: State, _: unknown, index_to_remove: number) => {
		return {
			...state,
			elements: state.elements.filter((_, index) => index != index_to_remove),
		};
	},
} as const;

type State = {
	elements: string[];
};

async function with_unit(s: HA_RESPONSE | Promise<HA_RESPONSE>) {
	s = await s;
	return `${s.state}${s.attributes.unit_of_measurement as string}`;
}

export default new (class DashboardPage extends StatefulPage<State, typeof actions> {
	actions = actions;

	getInitialState() {
		return { elements: ["one", "two", "three"] };
	}

	wrapInLayout(ctx: BaseContext, content: Templatable): Templatable {
		if (ctx.headers["just-data"]) {
			return content;
		} else {
			return html(ctx, "Dashboard", content, { navbar: () => "" });
		}
	}

	render(ctx: BaseContext, state: State, inputs: Record<string, string>) {
		const date = new Date();
		const stuff = [
			{ label: "Temperatura na balkonie", entity: "input_number.balkon_average" },
			{ label: "Temperatura w salonie", entity: "sensor.ewelink_th01_temperature" },
			{ label: "Wilgotność w salonie", entity: "sensor.ewelink_th01_humidity" },
			{ label: "Temperatura na strychu", entity: "sensor.strych_temperature_3" },
			{
				label: "Docelowa temp. na strychu",
				entity: "input_number.strych_target_temperature",
			},
		];

		return (
			<div style="font-size: 2rem">
				<div style="font-size: 10rem; text-align: center;">
					{date.getHours().toString().padStart(2, "0")}:
					{date.getMinutes().toString().padStart(2, "0")}
				</div>
				<table style="margin: 0 auto">
					<tbody>
						{stuff.map(({ label, entity }) => (
							<tr>
								<td style="text-align: right">{label}:</td>
								<td>
									<strong>{with_unit(get_state(entity))}</strong>
								</td>
							</tr>
						))}
					</tbody>
				</table>

				{ctx.headers["just-data"]
					? ""
					: /* HTML */ `<script>
							function refresh() {
								let xhr = new XMLHttpRequest();
								xhr.withCredentials = true;
								xhr.open("GET", "/dashboard");
								xhr.setRequestHeader("just-data", "true");

								xhr.onload = function () {
									document.querySelector("body").innerHTML =
										xhr.response;
								};
								xhr.send();
							}

							setInterval(refresh, 15 * 1000);
					  </script>`}
			</div>
		);
	}
})();
