import { withProdApp } from "../test_utils/with-prod-app.js";
import { VERY_LONG_TEST_TIMEOUT, webhintURL } from "../test_utils/webhint.js";
import { DashboardURL } from "./urls.js";
import { getBrowser } from "../test_utils/browser-creator.js";
import { Browser, BrowserContext, Page } from "@playwright/test";

describe("Dashboard webhint", () => {
	it(
		"doesn't crash",
		async function () {
			return withProdApp(async ({ base_url, rest_api }) => {
				await rest_api.get(DashboardURL);
				await webhintURL(base_url + DashboardURL);
				// alternatively you can use webhintHTML for faster but less precise scans
				// or for scanning responses of requests that use some form of authorization:
				// const response = await rest_api.get(DashboardURL);
				// await webhintHTML(response);
			});
		},
		VERY_LONG_TEST_TIMEOUT
	);
});

describe("Dashboard", () => {
	let page: Page;
	let browser: Browser;
	let context: BrowserContext;

	beforeEach(async () => {
		browser = await getBrowser();
		context = await browser.newContext();
		page = await context.newPage();
	});

	afterEach(async () => {
		await context.close();
	});

	it(
		"works as expected",
		async function () {
			return withProdApp(async ({ base_url }) => {
				await page.goto(base_url + DashboardURL);
			});
		},
		VERY_LONG_TEST_TIMEOUT
	);
});
